@@ -249,60 +249,6 @@ class TopSearchesPublic:
         return response
 
 
-class HashtagPublic:
-    def hashtag_info(self, hashtag, max_id=None):
-        params = {"max_id": max_id} if max_id else None
-        data = self.public_a1_request(
-            "/explore/tags/{hashtag!s}/".format(**{"hashtag": hashtag}), params=params
-        )
-        return data["hashtag"]
-
-    def hashtag_info_gql(self, hashtag, count=12, end_cursor=None):
-        variables = {
-            "tag_name": hashtag,
-            "show_ranked": False,
-            "first": int(count),
-        }
-        if end_cursor:
-            variables["after"] = end_cursor
-
-        data = self.public_graphql_request(
-            variables, query_hash="f92f56d47dc7a55b606908374b43a314"
-        )
-        return data["hashtag"]
-
-    def hashtag_top_feed(self, hashtag):
-        data = self.hashtag_info(hashtag)
-        return data["edge_hashtag_to_top_posts"]["edges"]
-
-    def hashtag_related_hashtags(self, hashtag):
-        data = self.hashtag_info(hashtag)
-        return [
-            item["node"]["name"]
-            for item in data["edge_hashtag_to_related_tags"]["edges"]
-        ]
-
-    def hashtag_feed(self, hashtag, count=70, sleep=2):
-        medias = []
-        end_cursor = None
-
-        while True:
-            data = self.hashtag_info(hashtag, end_cursor)
-            end_cursor = data["edge_hashtag_to_media"]["page_info"]["end_cursor"]
-            edges = data["edge_hashtag_to_media"]["edges"]
-            medias.extend(edges)
-
-            if (
-                not data["edge_hashtag_to_media"]["page_info"]["has_next_page"]
-                or len(medias) >= count
-            ):
-                break
-
-            time.sleep(sleep)
-
-        return medias[:count]
-
-
 class ProfilePublic:
     def location_feed(self, location_id, count=16, end_cursor=None):
         if count > 50:
